abacusai.code_llm_changed_files — AbacusAI documentation

# abacusai.code_llm_changed_files

## Classes

`CodeLlmChangedFiles` | Code changed files

## Module Contents

class abacusai.code_llm_changed_files.CodeLlmChangedFiles(client, addedFiles=None, updatedFiles=None, deletedFiles=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Code changed files

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - addedFiles (list) – A list of added file paths.

    - updatedFiles (list) – A list of updated file paths.

    - deletedFiles (list) – A list of deleted file paths.

  added_files = None
  updated_files = None
  deleted_files = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict